==> owncloud-10.0.7.tgz: owncloud/apps/files_sharing/l10n/gl.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Server to server sharing is not enabled on this server" : "Neste servidor non está activada a compartición de servidor a servidor",
    "The mountpoint name contains invalid characters." : "O nome do punto de montaxe contén caracteres incorrectos",
    "Invalid or untrusted SSL certificate" : "Certificado SSL incorrecto ou non fiábel",
    "Could not authenticate to remote share, password might be wrong" : "Non foi pisíbel autenticar na compartición remota, o contrasinal podería ser erróneo",
    "Storage not valid" : "Almacenamento incorrecto",
    "Couldn't add remote share" : "Non foi posíbel engadir a compartición remota",
    "Shared with you" : "Compartido con vostede",
    "Shared with others" : "Compartido con outros",
    "Shared by link" : "Compartido por ligazón",
    "Uploading..." : "Enviando...",
    "Nothing shared with you yet" : "Aínda non hai nada compartido con vostede.",
    "Files and folders others share with you will show up here" : "Os ficheiros e cartafoles que outros compartan con vostede amosaranse aquí",
    "Nothing shared yet" : "Aínda non hay nada compartido",
    "Files and folders you share will show up here" : "Os ficheiros e cartafoles que comparta amosaranse aquí",
    "No shared links" : "Non hai ligazóns compartidas",
    "Files and folders you share by link will show up here" : "Os ficheiros e cartafoles que comparta por ligazón amosaranse aquí",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Quere engadir a compartición remota {name} desde {owner}@{remote}?",
    "Remote share" : "Compartición remota",
    "Remote share password" : "Contrasinal da compartición remota",
    "Cancel" : "Cancelar",
    "Add remote share" : "Engadir unha compartición remota",
    "You can upload into this folder" : "Pode envialo a este cartafol",
    "No ownCloud installation (7 or higher) found at {remote}" : "Non se atopa unha instalación de ownCloud (7 ou superior) en {remote}",
    "Invalid ownCloud url" : "URL incorrecto do ownCloud",
    "Share" : "Compartir",
    "Shared by" : "Compartido por",
    "Sharing" : "Compartindo",
    "A file or folder has been <strong>shared</strong>" : "<strong>Compartiuse</strong> un ficheiro ou cartafol",
    "A file or folder was shared from <strong>another server</strong>" : "Compartiuse un ficheiro ou cartafol desde <strong>outro servidor</strong>",
    "A public shared file or folder was <strong>downloaded</strong>" : "Foi <strong>descargado</strong> un ficheiro ou cartafol público",
    "You received a new remote share %2$s from %1$s" : "Recibiu unha compartición remota %2$s de %1$s",
    "You received a new remote share from %s" : "Recibiu unha compartición remota de %s",
    "%1$s accepted remote share %2$s" : "%1$s comparticións remotas aceptadas %2$s",
    "%1$s declined remote share %2$s" : "%1$s comparticións remotas declinadas %2$s",
    "%1$s unshared %2$s from you" : "%1$s deixou de compartir %2$s con vostede",
    "Public shared folder %1$s was downloaded" : "Foi descargado o cartafol público %1$s",
    "Public shared file %1$s was downloaded" : "Foi descargado o ficheiro público %1$s",
    "You shared %1$s with %2$s" : "Compartiu %1$s con %2$s",
    "You shared %1$s with group %2$s" : "Compartiu %1$s co grupo %2$s",
    "You shared %1$s via link" : "Vostede compartiu %1$s mediante ligazón",
    "%2$s shared %1$s with you" : "%2$s compartiu %1$s con vostede",
    "Shares" : "Comparticións",
    "This share is password-protected" : "Esta compartición está protexida con contrasinal",
    "The password is wrong. Try again." : "O contrasinal é incorrecto. Ténteo de novo.",
    "Password" : "Contrasinal",
    "No entries found in this folder" : "Non se atoparon entradas neste cartafol",
    "Name" : "Nome",
    "Share time" : "Compartir o tempo",
    "Expiration date" : "Data de caducidade",
    "Sorry, this link doesn’t seem to work anymore." : "Semella que esta ligazón non funciona.",
    "Reasons might be:" : "As razóns poderían ser:",
    "the item was removed" : "o elemento foi retirado",
    "the link expired" : "a ligazón caducou",
    "sharing is disabled" : "foi desactivada a compartición",
    "For more info, please ask the person who sent this link." : "Para obter máis información, pregúntelle á persoa que lle enviou a ligazón.",
    "Add to your ownCloud" : "Engadir ao seu ownCloud",
    "Download" : "Descargar",
    "Download %s" : "Descargar %s",
    "Direct link" : "Ligazón directa"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-10.0.10.tgz: owncloud/apps/files_sharing/l10n/gl.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Server to server sharing is not enabled on this server" : "Neste servidor non está activada a compartición de servidor a servidor",
    "The mountpoint name contains invalid characters." : "O nome do punto de montaxe contén caracteres incorrectos",
    "Invalid or untrusted SSL certificate" : "Certificado SSL incorrecto ou non fiábel",
    "Could not authenticate to remote share, password might be wrong" : "Non foi pisíbel autenticar na compartición remota, o contrasinal podería ser erróneo",
    "Storage not valid" : "Almacenamento incorrecto",
    "Couldn't add remote share" : "Non foi posíbel engadir a compartición remota",
    "Shared with you" : "Compartido con vostede",
    "Shared with others" : "Compartido con outros",
    "Shared by link" : "Compartido por ligazón",
    "Uploading..." : "Enviando...",
    "Nothing shared with you yet" : "Aínda non hai nada compartido con vostede.",
    "Files and folders others share with you will show up here" : "Os ficheiros e cartafoles que outros compartan con vostede amosaranse aquí",
    "Nothing shared yet" : "Aínda non hay nada compartido",
    "Files and folders you share will show up here" : "Os ficheiros e cartafoles que comparta amosaranse aquí",
    "No shared links" : "Non hai ligazóns compartidas",
    "Files and folders you share by link will show up here" : "Os ficheiros e cartafoles que comparta por ligazón amosaranse aquí",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Quere engadir a compartición remota {name} desde {owner}@{remote}?",
    "Remote share" : "Compartición remota",
    "Remote share password" : "Contrasinal da compartición remota",
    "Cancel" : "Cancelar",
    "Add remote share" : "Engadir unha compartición remota",
    "You can upload into this folder" : "Pode envialo a este cartafol",
    "No ownCloud installation (7 or higher) found at {remote}" : "Non se atopa unha instalación de ownCloud (7 ou superior) en {remote}",
    "Invalid ownCloud url" : "URL incorrecto do ownCloud",
    "Share" : "Compartir",
    "Shared by" : "Compartido por",
    "Sharing" : "Compartindo",
    "A file or folder has been <strong>shared</strong>" : "<strong>Compartiuse</strong> un ficheiro ou cartafol",
    "A file or folder was shared from <strong>another server</strong>" : "Compartiuse un ficheiro ou cartafol desde <strong>outro servidor</strong>",
    "A public shared file or folder was <strong>downloaded</strong>" : "Foi <strong>descargado</strong> un ficheiro ou cartafol público",
    "You received a new remote share %2$s from %1$s" : "Recibiu unha compartición remota %2$s de %1$s",
    "You received a new remote share from %s" : "Recibiu unha compartición remota de %s",
    "%1$s accepted remote share %2$s" : "%1$s comparticións remotas aceptadas %2$s",
    "%1$s declined remote share %2$s" : "%1$s comparticións remotas declinadas %2$s",
    "%1$s unshared %2$s from you" : "%1$s deixou de compartir %2$s con vostede",
    "Public shared folder %1$s was downloaded" : "Foi descargado o cartafol público %1$s",
    "Public shared file %1$s was downloaded" : "Foi descargado o ficheiro público %1$s",
    "You shared %1$s with %2$s" : "Compartiu %1$s con %2$s",
    "You shared %1$s with group %2$s" : "Compartiu %1$s co grupo %2$s",
    "You shared %1$s via link" : "Vostede compartiu %1$s mediante ligazón",
    "%2$s shared %1$s with you" : "%2$s compartiu %1$s con vostede",
    "Shares" : "Comparticións",
    "This share is password-protected" : "Esta compartición está protexida con contrasinal",
    "The password is wrong. Try again." : "O contrasinal é incorrecto. Ténteo de novo.",
    "Password" : "Contrasinal",
    "No entries found in this folder" : "Non se atoparon entradas neste cartafol",
    "Name" : "Nome",
    "Share time" : "Compartir o tempo",
    "Expiration date" : "Data de caducidade",
    "Sorry, this link doesn’t seem to work anymore." : "Semella que esta ligazón non funciona.",
    "Reasons might be:" : "As razóns poderían ser:",
    "the item was removed" : "o elemento foi retirado",
    "the link expired" : "a ligazón caducou",
    "sharing is disabled" : "foi desactivada a compartición",
    "For more info, please ask the person who sent this link." : "Para obter máis información, pregúntelle á persoa que lle enviou a ligazón.",
    "Add to your ownCloud" : "Engadir ao seu ownCloud",
    "Download" : "Descargar",
    "Download %s" : "Descargar %s",
    "Direct link" : "Ligazón directa",
    "Pending" : "Pendentes",
    "Accept" : "Aceptar",
    "Declined" : "Rexeitado"
},
"nplurals=2; plural=(n != 1);");
